## 港股分钟行情

接口：hk_mins

描述：港股分钟数据，支持1min/5min/15min/30min/60min行情，提供Python SDK和 http Restful API两种方式

限量：单次最大8000行数据，可以通过股票代码和日期循环获取

权限：120积分可以调取2次接口查看数据，正式权限请参阅 权限说明  。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码，e.g.00001.HK |
| freq | str | Y | 分钟频度（1min/5min/15min/30min/60min） |
| start_date | datetime | N | 开始日期 格式：2023-03-13 09:00:00 |
| end_date | datetime | N | 结束时间 格式：2023-03-13 19:00:00 |

freq参数说明

| freq | 说明 |
| --- | --- |
| 1min | 1分钟 |
| 5min | 5分钟 |
| 15min | 15分钟 |
| 30min | 30分钟 |
| 60min | 60分钟 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_time | str | Y | 交易时间 |
| open | float | Y | 开盘价 |
| close | float | Y | 收盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| vol | int | Y | 成交量 |
| amount | float | Y | 成交金额 |

接口用法

```python
pro = ts.pro_api()

df = pro.hk_mins(ts_code='00001.HK', freq='1min', start_date='2023-03-13 09:00:00', end_date='2023-03-13 19:00:00')
```

数据样例

```python
ts_code                trade_time  open  close   high    low       vol      amount
0    00001.HK  2023-03-13 16:10:00  48.80  48.75  48.80  48.75  375500.0  18305625.0
```